<?php  
namespace Concrete\Package\FileReader\Block\FileReader;

defined('C5_EXECUTE') or die("Access Denied.");

use Concrete\Core\Block\BlockController;
use Loader;
use Package;
use Page;
use User;

class Controller extends BlockController
{

	protected $btTable 								= "btFileReader";
	protected $btInterfaceWidth 					= "400";
	protected $btInterfaceHeight 					= "230";
	protected $btCacheBlockOutput 					= false;
	protected $btCacheBlockOutputOnPost 			= false;
	protected $btCacheBlockOutputForRegisteredUsers = false;
	protected $btDefaultSet 						= 'basic';


	public function getBlockTypeDescription()
	{
		return t("Read and Render the content of a file directly inside the block");
	}

	public function getBlockTypeName()
	{
		return t("File Reader");
	}

	public function getJavaScriptStrings()
	{
		return array(
			'filename-required' => t('You must select a filename.')
		);
	}

	public function printFile()
	{
	    $pkg = Package::getByHandle('file_reader');

		$filename = $this->get('filename');
		if ( '' == $filename )
		{
			echo t("No filename specified");
			return;
		}

		if ( !file_exists( $filename ) )
		{
			echo t("File not found %s", $filename );
			return;
		}

		if ( !is_readable( $filename ) )
		{
			echo t("Access denied to %s", $filename );
			return;
		}

		if ( is_dir( $filename ) )
		{
			echo t("%s is a directory", $filename);
			return;
		}

		if ( ! $pkg->isActivated() )
		{
			echo t("File Reader globally deactivated");
			return;
		}
		
		$fh = \Core::make('helper/file');
		echo $fh->getContents( $filename );
	}

	public function view()
	{
		$this->set( 'activated', Package::getByHandle('file_reader')->isActivated() );
		$c = Page::getCurrentPage();
		$this->set( 'editMode', $editMode = $c->isEditMode() );

		if ( !$this->showToAnonymous && ! $editMode )
		{
			$user = new User();
			if ( ! $user->checkLogin() ) $this->set( 'activated', false );
		}
		$this->set('controller', $this );

	}

	public function action_on_file_refresh()
	{
		$this->printFile();
		exit;
	}


	public function save($args)
	{
		if ( !isset($args['showToAnonymous'] ) ) $args['showToAnonymous'] = 0;

		if ( !isset($args['refresh'] ) || $args['refresh'] == '' ) $args['refresh'] = 0;
		if ( !isset($args['filename'] ) ) $args['filename'] = '';

		$args['refresh'] = intval( $args['refresh'] );

		if ( count( $args['filename'] ) > 255 ) $args['filename'] = substr( $args['filename'], 0, 255 );

		parent::save($args);
	}
}

// vim: set noexpandtab ts=4 :
